@@ -49,12 +49,15 @@ MULTIPATH_PATH_CHECK_REGEX = re.compile("\s+\d+:\d+:\d+:\d+\s+")
 PLATFORM_ALL = 'ALL'
 PLATFORM_x86 = 'X86'
 PLATFORM_S390 = 'S390'
+PLATFORM_PPC64 = 'PPC64'
 OS_TYPE_ALL = 'ALL'
 OS_TYPE_LINUX = 'LINUX'
 OS_TYPE_WINDOWS = 'WIN'
 
 S390X = "s390x"
 S390 = "s390"
+PPC64 = "ppc64"
+PPC64LE = "ppc64le"
 
 ISCSI = "ISCSI"
 ISER = "ISER"
@@ -83,6 +86,8 @@ connector_list = [
     'os_brick.initiator.connectors.fibre_channel.FibreChannelConnector',
     ('os_brick.initiator.connectors.fibre_channel_s390x.'
      'FibreChannelConnectorS390X'),
+    ('os_brick.initiator.connectors.fibre_channel_ppc64.'
+     'FibreChannelConnectorPPC64'),
     'os_brick.initiator.connectors.aoe.AoEConnector',
     'os_brick.initiator.connectors.remotefs.RemoteFsConnector',
     'os_brick.initiator.connectors.rbd.RBDConnector',
@@ -167,6 +172,13 @@ _connector_mapping_linux_s390x = {
         'os_brick.initiator.connectors.gpfs.GPFSConnector',
 }
 
+# Mapping for the PPC64 platform
+_connector_mapping_linux_ppc64 = {
+    initiator.FIBRE_CHANNEL:
+        ('os_brick.initiator.connectors.fibre_channel_ppc64.'
+         'FibreChannelConnectorPPC64'),
+}
+
 # Mapping for the windows connectors
 _connector_mapping_windows = {
     initiator.ISCSI:
@@ -257,6 +269,9 @@ class InitiatorConnector(object):
             _mapping = _connector_mapping_windows
         elif arch in (initiator.S390, initiator.S390X):
             _mapping = _connector_mapping_linux_s390x
+        elif arch in (initiator.PPC64, initiator.PPC64LE):
+            _mapping = _connector_mapping_linux_ppc64
+
         else:
             _mapping = _connector_mapping_linux
 
