@@ -20,36 +20,30 @@ import os
 import re
 import tempfile
 
-from oslo_concurrency import processutils as putils
 from oslo_log import log as logging
 import six
 
 from os_brick import exception
-from os_brick.privileged import rootwrap as priv_rootwrap
-from os_brick.i18n import _, _LI
+from os_brick import executor
+from os_brick.i18n import _
 
 LOG = logging.getLogger(__name__)
 
 
-class RemoteFsClient(object):
+class RemoteFsClient(executor.Executor):
 
     def __init__(self, mount_type, root_helper,
                  execute=None, *args, **kwargs):
-        # For backwards compatibility, `putils.execute` is interpreted
-        # as a sentinel to mean "I want the os-brick default" :-/
-        # This can be burnt as soon as we update all the callsites (in
-        # nova+cinder) to the new default - and then we shall never
-        # speak of it again.
-        # TODO(gus): RemoteFsClient should probably inherit from Executor
-        if execute is None or execute == putils.execute:
-            execute = priv_rootwrap.execute
+        super(RemoteFsClient, self).__init__(root_helper, execute=execute,
+                                             *args, **kwargs)
 
         mount_type_to_option_prefix = {
             'nfs': 'nfs',
             'cifs': 'smbfs',
             'glusterfs': 'glusterfs',
             'vzstorage': 'vzstorage',
-            'quobyte': 'quobyte'
+            'quobyte': 'quobyte',
+            'scality': 'scality'
         }
 
         if mount_type not in mount_type_to_option_prefix:
@@ -68,18 +62,13 @@ class RemoteFsClient(object):
         if mount_type == "nfs":
             self._check_nfs_options()
 
-        self.root_helper = root_helper
-        self.set_execute(execute)
-
-    def set_execute(self, execute):
-        self._execute = execute
-
     def get_mount_base(self):
         return self._mount_base
 
     def _get_hash_str(self, base_str):
         """Return a string that represents hash of base_str
         (in a hex format).
+
         """
         if isinstance(base_str, six.text_type):
             base_str = base_str.encode('utf-8')
@@ -110,14 +99,12 @@ class RemoteFsClient(object):
         mount_path = self.get_mount_point(share)
 
         if mount_path in self._read_mounts():
-            LOG.info(_LI('Already mounted: %s'), mount_path)
+            LOG.info('Already mounted: %s', mount_path)
             return
 
         self._execute('mkdir', '-p', mount_path, check_exit_code=0)
         if self._mount_type == 'nfs':
             self._mount_nfs(share, mount_path, flags)
-        elif self._mount_type == 'vzstorage':
-            self._mount_vzstorage(share, mount_path, flags)
         else:
             self._do_mount(self._mount_type, share, mount_path,
                            self._mount_options, flags)
@@ -132,7 +119,7 @@ class RemoteFsClient(object):
             mnt_cmd.extend(flags)
         mnt_cmd.extend([share, mount_path])
 
-        self._execute(*mnt_cmd, root_helper=self.root_helper,
+        self._execute(*mnt_cmd, root_helper=self._root_helper,
                       run_as_root=True, check_exit_code=0)
 
     def _mount_nfs(self, nfs_share, mount_path, flags=None):
@@ -157,53 +144,6 @@ class RemoteFsClient(object):
                                        % {'sh': nfs_share,
                                           'error': mnt_errors})
 
-    def _vzstorage_write_mds_list(self, cluster_name, mdss):
-        tmp_dir = tempfile.mkdtemp(prefix='vzstorage-')
-        tmp_bs_path = os.path.join(tmp_dir, 'bs_list')
-        with open(tmp_bs_path, 'w') as f:
-            for mds in mdss:
-                f.write(mds + "\n")
-
-        conf_dir = os.path.join('/etc/pstorage/clusters', cluster_name)
-        if os.path.exists(conf_dir):
-            bs_path = os.path.join(conf_dir, 'bs_list')
-            self._execute('cp', '-f', tmp_bs_path, bs_path,
-                          root_helper=self.root_helper, run_as_root=True)
-        else:
-            self._execute('cp', '-rf', tmp_dir, conf_dir,
-                          root_helper=self.root_helper, run_as_root=True)
-        self._execute('chown', '-R', 'root:root', conf_dir,
-                      root_helper=self.root_helper, run_as_root=True)
-
-    def _mount_vzstorage(self, vz_share, mount_path, flags=None):
-        m = re.search("(?:(\S+):\/)?([a-zA-Z0-9_-]+)(?::(\S+))?", vz_share)
-        if not m:
-            msg = (_("Invalid Virtuozzo Storage share specification: %r."
-                     "Must be: [MDS1[,MDS2],...:/]<CLUSTER NAME>[:PASSWORD].")
-                   % vz_share)
-            raise exception.BrickException(msg)
-
-        mdss = m.group(1)
-        cluster_name = m.group(2)
-        passwd = m.group(3)
-
-        if mdss:
-            mdss = mdss.split(',')
-            self._vzstorage_write_mds_list(cluster_name, mdss)
-
-        if passwd:
-            self._execute('pstorage', '-c', cluster_name, 'auth-node', '-P',
-                          process_input=passwd,
-                          root_helper=self.root_helper, run_as_root=True)
-
-        mnt_cmd = ['pstorage-mount', '-c', cluster_name]
-        if flags:
-            mnt_cmd.extend(flags)
-        mnt_cmd.extend([mount_path])
-
-        self._execute(*mnt_cmd, root_helper=self.root_helper,
-                      run_as_root=True, check_exit_code=0)
-
     def _check_nfs_options(self):
         """Checks and prepares nfs mount type options."""
         self._nfs_mount_type_opts = {'nfs': self._mount_options}
@@ -243,14 +183,15 @@ class RemoteFsClient(object):
 class ScalityRemoteFsClient(RemoteFsClient):
     def __init__(self, mount_type, root_helper,
                  execute=None, *args, **kwargs):
+        super(ScalityRemoteFsClient, self).__init__(mount_type, root_helper,
+                                                    execute=execute,
+                                                    *args, **kwargs)
         self._mount_type = mount_type
         self._mount_base = kwargs.get(
             'scality_mount_point_base', "").rstrip('/')
         if not self._mount_base:
             raise exception.InvalidParameterValue(
                 err=_('scality_mount_point_base required'))
-        self.root_helper = root_helper
-        self.set_execute(execute or putils.execute)
         self._mount_options = None
 
     def get_mount_point(self, device_name):
@@ -266,8 +207,58 @@ class ScalityRemoteFsClient(RemoteFsClient):
         same method signature for class inheritance purpose.
         """
         if self._mount_base in self._read_mounts():
-            LOG.info(_LI('Already mounted: %s'), self._mount_base)
+            LOG.info('Already mounted: %s', self._mount_base)
             return
         self._execute('mkdir', '-p', self._mount_base, check_exit_code=0)
         super(ScalityRemoteFsClient, self)._do_mount(
             'sofs', '/etc/sfused.conf', self._mount_base)
+
+
+class VZStorageRemoteFSClient(RemoteFsClient):
+    def _vzstorage_write_mds_list(self, cluster_name, mdss):
+        tmp_dir = tempfile.mkdtemp(prefix='vzstorage-')
+        tmp_bs_path = os.path.join(tmp_dir, 'bs_list')
+        with open(tmp_bs_path, 'w') as f:
+            for mds in mdss:
+                f.write(mds + "\n")
+
+        conf_dir = os.path.join('/etc/pstorage/clusters', cluster_name)
+        if os.path.exists(conf_dir):
+            bs_path = os.path.join(conf_dir, 'bs_list')
+            self._execute('cp', '-f', tmp_bs_path, bs_path,
+                          root_helper=self._root_helper, run_as_root=True)
+        else:
+            self._execute('cp', '-rf', tmp_dir, conf_dir,
+                          root_helper=self._root_helper, run_as_root=True)
+        self._execute('chown', '-R', 'root:root', conf_dir,
+                      root_helper=self._root_helper, run_as_root=True)
+
+    def _do_mount(self, mount_type, vz_share, mount_path,
+                  mount_options=None, flags=None):
+        m = re.search("(?:(\S+):\/)?([a-zA-Z0-9_-]+)(?::(\S+))?", vz_share)
+        if not m:
+            msg = (_("Invalid Virtuozzo Storage share specification: %r."
+                     "Must be: [MDS1[,MDS2],...:/]<CLUSTER NAME>[:PASSWORD].")
+                   % vz_share)
+            raise exception.BrickException(msg)
+
+        mdss = m.group(1)
+        cluster_name = m.group(2)
+        passwd = m.group(3)
+
+        if mdss:
+            mdss = mdss.split(',')
+            self._vzstorage_write_mds_list(cluster_name, mdss)
+
+        if passwd:
+            self._execute('pstorage', '-c', cluster_name, 'auth-node', '-P',
+                          process_input=passwd,
+                          root_helper=self._root_helper, run_as_root=True)
+
+        mnt_cmd = ['pstorage-mount', '-c', cluster_name]
+        if flags:
+            mnt_cmd.extend(flags)
+        mnt_cmd.extend([mount_path])
+
+        self._execute(*mnt_cmd, root_helper=self._root_helper,
+                      run_as_root=True, check_exit_code=0)
