@@ -14,6 +14,7 @@
 import ddt
 import mock
 
+from os_brick import exception
 from os_brick.initiator.connectors import rbd
 from os_brick.initiator import linuxrbd
 from os_brick.privileged import rootwrap as priv_rootwrap
@@ -33,7 +34,7 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
         self.clustername = 'fake_ceph'
         self.hosts = ['192.168.10.2']
         self.ports = ['6789']
-        self.keyring = '/etc/ceph/ceph.client.cinder.keyring'
+        self.keyring = "[client.cinder]\n  key = test\n"
 
         self.connection_properties = {
             'auth_username': self.user,
@@ -41,6 +42,7 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
             'cluster_name': self.clustername,
             'hosts': self.hosts,
             'ports': self.ports,
+            'keyring': self.keyring,
         }
 
     def test_get_search_path(self):
@@ -99,16 +101,40 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
     @mock.patch('os_brick.initiator.linuxrbd.rados')
     @mock.patch.object(rbd.RBDConnector, '_create_ceph_conf')
     @mock.patch('os.path.exists')
-    def test_custom_keyring(self, mock_path, mock_conf, mock_rados, mock_rbd):
+    def test_provided_keyring(self, mock_path, mock_conf, mock_rados,
+                              mock_rbd):
         conn = rbd.RBDConnector(None)
         mock_path.return_value = False
         mock_conf.return_value = "/tmp/fake_dir/fake_ceph.conf"
-        custom_keyring_path = "/foo/bar/baz"
-        self.connection_properties['keyring'] = custom_keyring_path
+        self.connection_properties['keyring'] = self.keyring
         conn.connect_volume(self.connection_properties)
         mock_conf.assert_called_once_with(self.hosts, self.ports,
                                           self.clustername, self.user,
-                                          custom_keyring_path)
+                                          self.keyring)
+
+    def test_keyring_is_none(self):
+        conn = rbd.RBDConnector(None)
+        keyring = None
+        keyring_data = "[client.cinder]\n  key = test\n"
+        mockopen = mock.mock_open(read_data=keyring_data)
+        mockopen.return_value.__exit__ = mock.Mock()
+        with mock.patch('os_brick.initiator.connectors.rbd.open', mockopen,
+                        create=True):
+            self.assertEqual(
+                conn._check_or_get_keyring_contents(keyring, 'cluster',
+                                                    'user'), keyring_data)
+
+    def test_keyring_raise_error(self):
+        conn = rbd.RBDConnector(None)
+        keyring = None
+        mockopen = mock.mock_open()
+        mockopen.return_value = ""
+        with mock.patch('os_brick.initiator.connectors.rbd.open', mockopen,
+                        create=True) as mock_keyring_file:
+            mock_keyring_file.side_effect = IOError
+            self.assertRaises(exception.BrickException,
+                              conn._check_or_get_keyring_contents, keyring,
+                              'cluster', 'user')
 
     @ddt.data((['192.168.1.1', '192.168.1.2'],
                ['192.168.1.1', '192.168.1.2']),
@@ -146,16 +172,44 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
     @mock.patch.object(priv_rootwrap, 'execute', return_value=None)
     def test_connect_local_volume(self, mock_execute):
         rbd_connector = rbd.RBDConnector(None, do_local_attach=True)
-        conn = {'name': 'pool/image'}
+        conn = {'name': 'pool/image',
+                'auth_username': 'fake_user',
+                'hosts': ['192.168.10.2'],
+                'ports': ['6789']}
         device_info = rbd_connector.connect_volume(conn)
         execute_call1 = mock.call('which', 'rbd')
-        cmd = ['rbd', 'map', 'image', '--pool', 'pool']
+        cmd = ['rbd', 'map', 'image', '--pool', 'pool', '--id', 'fake_user',
+               '--mon_host', '192.168.10.2:6789']
         execute_call2 = mock.call(*cmd, root_helper=None, run_as_root=True)
         mock_execute.assert_has_calls([execute_call1, execute_call2])
         expected_info = {'path': '/dev/rbd/pool/image',
                          'type': 'block'}
         self.assertEqual(expected_info, device_info)
 
+    @mock.patch.object(priv_rootwrap, 'execute', return_value=None)
+    def test_connect_local_volume_without_mons(self, mock_execute):
+        rbd_connector = rbd.RBDConnector(None, do_local_attach=True)
+        conn = {'name': 'pool/image',
+                'auth_username': 'fake_user'}
+        device_info = rbd_connector.connect_volume(conn)
+        execute_call1 = mock.call('which', 'rbd')
+        cmd = ['rbd', 'map', 'image', '--pool', 'pool', '--id', 'fake_user']
+        execute_call2 = mock.call(*cmd, root_helper=None, run_as_root=True)
+        mock_execute.assert_has_calls([execute_call1, execute_call2])
+        expected_info = {'path': '/dev/rbd/pool/image',
+                         'type': 'block'}
+        self.assertEqual(expected_info, device_info)
+
+    @mock.patch.object(priv_rootwrap, 'execute', return_value=None)
+    def test_connect_local_volume_without_auth(self, mock_execute):
+        rbd_connector = rbd.RBDConnector(None, do_local_attach=True)
+        conn = {'name': 'pool/image',
+                'hosts': ['192.168.10.2'],
+                'ports': ['6789']}
+        self.assertRaises(exception.BrickException,
+                          rbd_connector.connect_volume,
+                          conn)
+
     @mock.patch('os_brick.initiator.linuxrbd.rbd')
     @mock.patch('os_brick.initiator.linuxrbd.rados')
     @mock.patch.object(linuxrbd.RBDVolumeIOWrapper, 'close')
@@ -171,11 +225,15 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
     @mock.patch.object(priv_rootwrap, 'execute', return_value=None)
     def test_disconnect_local_volume(self, mock_execute):
         rbd_connector = rbd.RBDConnector(None, do_local_attach=True)
-        conn = {'name': 'pool/image'}
+        conn = {'name': 'pool/image',
+                'auth_username': 'fake_user',
+                'hosts': ['192.168.10.2'],
+                'ports': ['6789']}
         rbd_connector.disconnect_volume(conn, None)
 
         dev_name = '/dev/rbd/pool/image'
-        cmd = ['rbd', 'unmap', dev_name]
+        cmd = ['rbd', 'unmap', dev_name, '--id', 'fake_user',
+               '--mon_host', '192.168.10.2:6789']
         mock_execute.assert_called_once_with(*cmd, root_helper=None,
                                              run_as_root=True)
 
