@@ -18,6 +18,7 @@ import textwrap
 import time
 
 import mock
+from oslo_concurrency import processutils as putils
 from oslo_log import log as logging
 
 from os_brick import exception
@@ -95,6 +96,24 @@ class LinuxSCSITestCase(base.TestCase):
         expected_commands = [('multipath -f /dev/dm-9')]
         self.assertEqual(expected_commands, self.cmds)
 
+    @mock.patch('retrying.time.sleep', mock.Mock())
+    def test_flush_multipath_device_in_use(self):
+        side_effect = (
+            putils.ProcessExecutionError(
+                stdout='Feb 09 14:38:02 | mpatha: map in use\n'
+                       'Feb 09 14:38:02 | failed to remove multipath map '
+                       'mpatha\n',
+                exit_code=1),
+            ('', '')
+        )
+
+        with mock.patch.object(self.linuxscsi, '_execute') as execute_mock:
+            execute_mock.side_effect = side_effect
+            self.linuxscsi.flush_multipath_device('mpatha')
+            execute_mock.assert_has_calls(
+                [mock.call('multipath', '-f', 'mpatha', run_as_root=True,
+                           root_helper=mock.ANY)] * 2)
+
     def test_flush_multipath_devices(self):
         self.linuxscsi.flush_multipath_devices()
         expected_commands = [('multipath -F')]
@@ -138,8 +157,7 @@ class LinuxSCSITestCase(base.TestCase):
     def test_find_multipath_device_path_fail(self, exists_mock, sleep_mock):
         fake_wwn = '1234567890'
         found_path = self.linuxscsi.find_multipath_device_path(fake_wwn)
-        expected_path = None
-        self.assertEqual(expected_path, found_path)
+        self.assertIsNone(found_path)
 
     @mock.patch.object(os.path, 'exists', return_value=False)
     @mock.patch.object(time, 'sleep')
@@ -161,6 +179,7 @@ class LinuxSCSITestCase(base.TestCase):
 
             info = {"device": "dm-3",
                     "id": "350002ac20398383d",
+                    "name": "mpatha",
                     "devices": devices}
             return info
 
@@ -168,7 +187,7 @@ class LinuxSCSITestCase(base.TestCase):
 
         self.linuxscsi.remove_multipath_device('/dev/dm-3')
         expected_commands = [
-            ('multipath -f 350002ac20398383d'),
+            ('multipath -f mpatha'),
             ('blockdev --flushbufs /dev/sde'),
             ('tee -a /sys/block/sde/device/delete'),
             ('blockdev --flushbufs /dev/sdf'),
